# -*- coding: ISO-8859-1 -*-
# Copyright (C) 2004-2005 Luis Belmar-Letelier <luis@itaapy.com>
#               2005 Alexandre Fernandez <alex@itaapy.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# Import from itools
from itools.web import get_context
from itools.xml.stl import stl

# Import from itools.cms
from itools.cms.Root import Root as ikaaroRoot
from itools.cms.Folder import Folder as ikaaroFolder
from itools.cms.Document import HTML as ikaaroHTML
from itools.cms.Handler import Handler as ikaaroHandler
from itools.cms.File import File as ikaaroFile


class Base(object):

    view__label__ = u'Preview'
    view__access__ = True
    def view(self):
        """ 
        The main backoffice view method, used to show folders and documents 
        """
        namespace = {}
        here = get_context().handler
        handlers = here.search_handlers(format='Document')
        #print list(handlers)
        documents = [{'url': '%s/;view' % here.get_pathto(h),
                      'name': h.title or h.name} for h in handlers]
        namespace['docs'] = documents

        handlers = here.search_handlers(format='PortalFolder')
        folders = [{'url': '%s/;view' % here.get_pathto(h),
                    'name': h.title or h.name} for h in handlers] 
        namespace['folders'] = folders
        namespace['title'] = self.title or self.name

        handler = self.get_handler('/ui/frontoffice1/Base_view.xml')
        return stl(handler, namespace)


    switch_skin__label__ = u"Switch skin"
    switch_skin__access__ = True
    def switch_skin(self):
        context = get_context()
        request, response = context.request, context.response
        root, here  = context.root, context.handler

        print 'in switch_skin', request.get_cookies_as_str()

        cookie = context.get_cookie('skin_path') or 'ui/aruni'
        #print 'in switch_skin before switch ', cookie
        if cookie == 'ui/frontoffice1':
            context.set_cookie('skin_path', 'ui/aruni', path='/')
            response.redirect(request.referrer)
        elif cookie == 'ui/aruni':
            context.set_cookie('skin_path', 'ui/frontoffice1', path='/')
            response.redirect('%s/;view' % here.get_pathto(root))


class Root(Base, ikaaroRoot):

    class_id = 'Portal'
    class_title = u'Portal four'
    class_version = '20041106'


    def get_skin(self):
        """ this method need to be define in the Root class"""
        context = get_context()
        request, response = context.request, context.response

        cookie = context.get_cookie('skin_path') 
        if cookie == 'ui/frontoffice1':
            # return the frontoffice skin
            return self.get_handler(cookie)
        # return the default skin
        return self.get_handler('ui/aruni')


    def get_views(self):
        views = ikaaroFolder.get_views(self)
        views += ['view', 'switch_skin']
        return views


    def get_document_types(self):
        types = ikaaroRoot.get_document_types(self)
        return types + [PortalFolder]

ikaaroRoot.register_handler_class(Root)



class PortalFolder(Base, ikaaroFolder):

    class_id = 'PortalFolder'
    class_title = u'Our Portal Folder'
    class_description = u'Here the description of our Portal Folder'
    class_version = '20050125'
    class_icon48 = 'frontoffice1/images/Folder48.png'
    class_icon16 = 'frontoffice1/images/Folder16.png'


    def get_document_types(self):
         return [Document, PortalFolder, ikaaroFile]


    def get_views(self):
        views = ikaaroFolder.get_views(self)
        views += ['view', 'switch_skin']
        return views

ikaaroFolder.register_handler_class(PortalFolder)



class Document(Base, ikaaroHTML):

    class_id = 'Document'
    class_title = u'Our Document'
    class_description = u'Here the description of our special Document Type'
    class_version = '20041106'
    class_icon48 = 'frontoffice1/images/Document48.png'
    class_icon16 = 'frontoffice1/images/Document16.png'


    view__label__ = u'Preview'
    view__access__ = True
    def view(self):
        namespace = {}
        namespace['title'] = self.title or self.name
        namespace['body'] = self.to_xhtml_body()
        handler = self.get_handler('/ui/frontoffice1/Document_view.xml')
        return stl(handler, namespace)


    def get_views(self):
        views = ikaaroHTML.get_views(self)
        views += ['view', 'switch_skin']
        return views

ikaaroHTML.register_handler_class(Document)
